==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/hu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "A megadott operátor érvénytelen",
    "The given regular expression is invalid" : "A megadott reguláris kifejezés érvénytelen",
    "The given file size is invalid" : "A megadott fájlméret érvénytelen",
    "The given tag id is invalid" : "A megadott címkeazonosító érvénytelen",
    "The given IP range is invalid" : "A megadott IP-tartomány érvénytelen",
    "The given IP range is not valid for IPv4" : "A megadott IPv4-tartomány érvénytelen",
    "The given IP range is not valid for IPv6" : "A megadott IPv6-tartomány érvénytelen",
    "The given time span is invalid" : "A megadott időtartam érvénytelen",
    "The given start time is invalid" : "A megadott kezdési idő érvénytelen",
    "The given end time is invalid" : "A megadott befejezési idő érvénytelen",
    "The given group does not exist" : "A megadott csoport nem létezik",
    "File" : "Fájl",
    "File created" : "A fájl létrehozva",
    "File updated" : "A fájl frissítve",
    "File renamed" : "A fájl átnevezve",
    "File deleted" : "A fájl törölve",
    "File accessed" : "Hozzáférés a fájlhoz",
    "File copied" : "A fájl másolva",
    "Tag assigned" : "Címke hozzárendelve",
    "Someone" : "Valaki",
    "%s created %s" : "%s létrehozta a következőt: %s",
    "%s modified %s" : "%s módosította a következőt: %s",
    "%s deleted %s" : "%s törölte a következőt: %s",
    "%s accessed %s" : "%s hozzáfért a következőhöz: %s",
    "%s renamed %s" : "%s átnevezte a következőt: %s",
    "%s copied %s" : "%s átmásolta a következőt: %s",
    "%s assigned %s to %s" : "%s hozzárendelte a következőt: %s, hozzá: %s",
    "Operation #%s does not exist" : "A(z) #%s művelet nem létezik",
    "Entity %s does not exist" : "A(z) %s entitás nem létezik",
    "Entity %s is invalid" : "A(z) %s entitás érvénytelen",
    "No events are chosen." : "Nincs kiválasztva esemény.",
    "Entity %s has no event %s" : "A(z) %s entitásnak nincs eseménye %s",
    "Operation %s does not exist" : "A(z) %s művelet nem létezik",
    "Operation %s is invalid" : "A(z) #%s művelet érvénytelen",
    "At least one check needs to be provided" : "Legalább egy ellenőrzést meg kell adni",
    "The provided operation data is too long" : "A megadott műveleti adatok túl hosszúak",
    "Invalid check provided" : "Érvénytelen ellenőrzést adott meg",
    "Check %s does not exist" : "A(z) %s nem létezik, ellenőrizze",
    "Check %s is invalid" : "A(z) %s érvénytelen, ellenőrizze",
    "Check %s is not allowed with this entity" : "A(z) %s ellenőrzés nem engedélyezett ezzel az entitással",
    "The provided check value is too long" : "A megadott ellenőrzési érték túl hosszú",
    "Check #%s does not exist" : "A(z) #%s nem létezik, ellenőrizze",
    "Check %s is invalid or does not exist" : "A(z) %s érvénytelen vagy nem létezik, ellenőrizze",
    "Flow" : "Folyamat",
    "Nextcloud workflow engine" : "Nextcloud munkafolyamat-motor",
    "Select a filter" : "Válasszon szűrőt",
    "Select a comparator" : "Válasszon összehasonlítót",
    "Remove filter" : "Szűrő eltávolítása",
    "Audio" : "Hangok",
    "Folder" : "Mappa",
    "Images" : "Képek",
    "Office documents" : "Irodai dokumentumok",
    "PDF documents" : "PDF-dokumentumok",
    "Video" : "Videó",
    "Custom MIME type" : "Egyéni MIME-típus",
    "Custom mimetype" : "Egyéni MIME-típus",
    "Select a file type" : "Válasszon fájltípust",
    "e.g. httpd/unix-directory" : "például httpd/unix-directory",
    "Please enter a valid time span" : "Érvényes időtartamot adjon meg",
    "Files WebDAV" : "WebDAV-fájlok",
    "Custom URL" : "Egyéni URL",
    "Select a request URL" : "Válassza ki a kérés URL-jét",
    "Android client" : "Android kliens",
    "iOS client" : "iOS klens",
    "Desktop client" : "Asztali kliens",
    "Thunderbird & Outlook addons" : "Thunderbird és Outlook kiegészítők",
    "Custom user agent" : "Egyéni felhasználói ügynök",
    "Select a user agent" : "Válasszon felhasználói ügynököt",
    "Select groups" : "Csoportok kiválasztása",
    "Groups" : "Csoportok",
    "Type to search for group …" : "Gépeljen az csoport kereséséhez…",
    "Select a trigger" : "Válasszon feltételt",
    "At least one event must be selected" : "Legalább egy eseményt ki kell választani",
    "Add new flow" : "Új folyamat hozzáadása",
    "The configuration is invalid" : "A konfiguráció érvénytelen",
    "Active" : "Aktív",
    "Save" : "Mentés",
    "When" : "Mikor",
    "and" : "és",
    "Add a new filter" : "Új szűrő hozzáadása",
    "Cancel" : "Mégse",
    "Delete" : "Törlés",
    "Available flows" : "Rendelkezésre álló folyamatok",
    "For details on how to write your own flow, check out the development documentation." : "A saját folyamatának megírásának részleteiért lásd a fejlesztési dokumentációt.",
    "No flows installed" : "Nincsenek telepített folyamatok",
    "Ask your administrator to install new flows." : "Kérje meg a rendszergazdát, hogy telepítsen új folyamatokat.",
    "More flows" : "Több folyamat",
    "Browse the App Store" : "Alkalmazástár böngészése",
    "Show less" : "Kevesebb megjelenítése",
    "Show more" : "Több megjelenítése",
    "Configured flows" : "Beállított folyamatok",
    "Your flows" : "Az Ön folyamatai",
    "No flows configured" : "Nincsenek beállított folyamatok",
    "matches" : "egyezik",
    "does not match" : "nem egyezik",
    "is" : "ez",
    "is not" : "nem ez",
    "File name" : "Fájlnév",
    "File MIME type" : "Fájl MIME-típusa",
    "File size (upload)" : "Fájlméret (feltöltés)",
    "less" : "kisebb",
    "less or equals" : "kisebb vagy egyenlő",
    "greater or equals" : "nagyobb vagy egyenlő",
    "greater" : "nagyobb",
    "Request remote address" : "Távoli cím kérése",
    "matches IPv4" : "IPv4 egyezik",
    "does not match IPv4" : "IPv4 nem egyezik",
    "matches IPv6" : "IPv6 egyezik",
    "does not match IPv6" : "IPv6 nem egyezik",
    "File system tag" : "Fájlrendszercímke",
    "is tagged with" : "címkézve ezzel",
    "is not tagged with" : "nincs címkézve ezzel",
    "Request URL" : "Kérés URL-je",
    "Request time" : "Kérés ideje",
    "between" : "közötte",
    "not between" : "nincs közötte",
    "Request user agent" : "Kérés felhasználói ügynöke",
    "Group membership" : "Csoporttagság",
    "is member of" : "tagja ennek",
    "is not member of" : "nem tagja ennek"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/hu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "A megadott operátor érvénytelen",
    "The given regular expression is invalid" : "A megadott reguláris kifejezés érvénytelen",
    "The given file size is invalid" : "A megadott fájlméret érvénytelen",
    "The given tag id is invalid" : "A megadott címkeazonosító érvénytelen",
    "The given IP range is invalid" : "A megadott IP-tartomány érvénytelen",
    "The given IP range is not valid for IPv4" : "A megadott IPv4-tartomány érvénytelen",
    "The given IP range is not valid for IPv6" : "A megadott IPv6-tartomány érvénytelen",
    "The given time span is invalid" : "A megadott időtartam érvénytelen",
    "The given start time is invalid" : "A megadott kezdési idő érvénytelen",
    "The given end time is invalid" : "A megadott befejezési idő érvénytelen",
    "The given group does not exist" : "A megadott csoport nem létezik",
    "File" : "Fájl",
    "File created" : "A fájl létrehozva",
    "File updated" : "A fájl frissítve",
    "File renamed" : "A fájl átnevezve",
    "File deleted" : "A fájl törölve",
    "File accessed" : "Hozzáférés a fájlhoz",
    "File copied" : "A fájl másolva",
    "Tag assigned" : "Címke hozzárendelve",
    "Someone" : "Valaki",
    "%s created %s" : "%s létrehozta a következőt: %s",
    "%s modified %s" : "%s módosította a következőt: %s",
    "%s deleted %s" : "%s törölte a következőt: %s",
    "%s accessed %s" : "%s hozzáfért a következőhöz: %s",
    "%s renamed %s" : "%s átnevezte a következőt: %s",
    "%s copied %s" : "%s átmásolta a következőt: %s",
    "%s assigned %s to %s" : "%s hozzárendelte a következőt: %s, hozzá: %s",
    "Operation #%s does not exist" : "A(z) #%s művelet nem létezik",
    "Entity %s does not exist" : "A(z) %s entitás nem létezik",
    "Entity %s is invalid" : "A(z) %s entitás érvénytelen",
    "No events are chosen." : "Nincs kiválasztva esemény.",
    "Entity %s has no event %s" : "A(z) %s entitásnak nincs eseménye %s",
    "Operation %s does not exist" : "A(z) %s művelet nem létezik",
    "Operation %s is invalid" : "A(z) #%s művelet érvénytelen",
    "At least one check needs to be provided" : "Legalább egy ellenőrzést meg kell adni",
    "The provided operation data is too long" : "A megadott műveleti adatok túl hosszúak",
    "Invalid check provided" : "Érvénytelen ellenőrzést adott meg",
    "Check %s does not exist" : "A(z) %s nem létezik, ellenőrizze",
    "Check %s is invalid" : "A(z) %s érvénytelen, ellenőrizze",
    "Check %s is not allowed with this entity" : "A(z) %s ellenőrzés nem engedélyezett ezzel az entitással",
    "The provided check value is too long" : "A megadott ellenőrzési érték túl hosszú",
    "Check #%s does not exist" : "A(z) #%s nem létezik, ellenőrizze",
    "Check %s is invalid or does not exist" : "A(z) %s érvénytelen vagy nem létezik, ellenőrizze",
    "Flow" : "Folyamat",
    "Nextcloud workflow engine" : "Nextcloud munkafolyamat-motor",
    "Select a filter" : "Válasszon szűrőt",
    "Select a comparator" : "Válasszon összehasonlítót",
    "Remove filter" : "Szűrő eltávolítása",
    "Audio" : "Hang",
    "Folder" : "Mappa",
    "Images" : "Képek",
    "Office documents" : "Irodai dokumentumok",
    "PDF documents" : "PDF-dokumentumok",
    "Video" : "Videó",
    "Custom MIME type" : "Egyéni MIME-típus",
    "Custom mimetype" : "Egyéni MIME-típus",
    "Select a file type" : "Válasszon fájltípust",
    "e.g. httpd/unix-directory" : "például httpd/unix-directory",
    "Please enter a valid time span" : "Érvényes időtartamot adjon meg",
    "Files WebDAV" : "WebDAV-fájlok",
    "Custom URL" : "Egyéni webcím",
    "Select a request URL" : "Válassza ki a kérés webcímét",
    "Android client" : "Android kliens",
    "iOS client" : "iOS klens",
    "Desktop client" : "Asztali kliens",
    "Thunderbird & Outlook addons" : "Thunderbird és Outlook kiegészítők",
    "Custom user agent" : "Egyéni felhasználói ügynök",
    "Select a user agent" : "Válasszon felhasználói ügynököt",
    "Select groups" : "Csoportok kiválasztása",
    "Groups" : "Csoportok",
    "Type to search for group …" : "Gépeljen egy csoport kereséséhez…",
    "Select a trigger" : "Válasszon feltételt",
    "At least one event must be selected" : "Legalább egy eseményt ki kell választani",
    "Add new flow" : "Új folyamat hozzáadása",
    "The configuration is invalid" : "A konfiguráció érvénytelen",
    "Active" : "Aktív",
    "Save" : "Mentés",
    "When" : "Mikor",
    "and" : "és",
    "Add a new filter" : "Új szűrő hozzáadása",
    "Cancel" : "Mégse",
    "Delete" : "Törlés",
    "Available flows" : "Rendelkezésre álló folyamatok",
    "For details on how to write your own flow, check out the development documentation." : "A saját folyamatának megírásának részleteiért lásd a fejlesztési dokumentációt.",
    "No flows installed" : "Nincsenek telepített folyamatok",
    "Ask your administrator to install new flows." : "Kérje meg a rendszergazdát, hogy telepítsen új folyamatokat.",
    "More flows" : "Több folyamat",
    "Browse the App Store" : "Alkalmazástár böngészése",
    "Show less" : "Kevesebb megjelenítése",
    "Show more" : "Több megjelenítése",
    "Configured flows" : "Beállított folyamatok",
    "Your flows" : "Az Ön folyamatai",
    "No flows configured" : "Nincsenek beállított folyamatok",
    "matches" : "egyezik",
    "does not match" : "nem egyezik",
    "is" : "ez",
    "is not" : "nem ez",
    "File name" : "Fájlnév",
    "File MIME type" : "Fájl MIME-típusa",
    "File size (upload)" : "Fájlméret (feltöltés)",
    "less" : "kisebb",
    "less or equals" : "kisebb vagy egyenlő",
    "greater or equals" : "nagyobb vagy egyenlő",
    "greater" : "nagyobb",
    "Request remote address" : "Távoli cím kérése",
    "matches IPv4" : "IPv4 egyezik",
    "does not match IPv4" : "IPv4 nem egyezik",
    "matches IPv6" : "IPv6 egyezik",
    "does not match IPv6" : "IPv6 nem egyezik",
    "File system tag" : "Fájlrendszercímke",
    "is tagged with" : "címkézve ezzel",
    "is not tagged with" : "nincs címkézve ezzel",
    "Request URL" : "Kérés URL-je",
    "Request time" : "Kérés ideje",
    "between" : "közötte",
    "not between" : "nincs közötte",
    "Request user agent" : "Kérés felhasználói ügynöke",
    "Group membership" : "Csoporttagság",
    "is member of" : "tagja ennek",
    "is not member of" : "nem tagja ennek",
    "Type to search for group …" : "Gépeljen egy csoport kereséséhez…"
},
"nplurals=2; plural=(n != 1);");
